-- enable long transaction support
SELECT postgis_EnableLongTransactions();

CREATE TABLE test_long_term_locks (id INTEGER NOT NULL, state VARCHAR(32));

INSERT INTO test_long_term_locks(id, state) VALUES (1000, '');
INSERT INTO test_long_term_locks(id, state) VALUES (2000, '');
INSERT INTO test_long_term_locks(id, state) VALUES (3000, '');

-- enable locks checking on the table
SELECT postgis_CheckAuth('test_long_term_locks', 'id');

-- update the state for all the long term locks
UPDATE test_long_term_locks SET state = 'default';

-- place the locks
SELECT postgis_LockRow('test_long_term_locks', '1000', 'auth1000', now()::TIMESTAMP + '00:01');
SELECT postgis_LockRow('test_long_term_locks', '2000', 'auth1000', now()::TIMESTAMP + '00:01');
SELECT postgis_LockRow('test_long_term_locks', '3000', 'auth3000', now()::TIMESTAMP + '00:01');

-- this should fail due to missing auth
UPDATE test_long_term_locks SET state = 'unauthorized' WHERE id = 1000;

BEGIN;

	-- add authorization for row 1000
	SELECT postgis_AddAuth('auth1000');
	
	-- we're authorized for row 1000
	UPDATE test_long_term_locks SET state = 'authorized' WHERE id = 1000;

END;

-- release the auth1000 locks
SELECT postgis_UnlockRows('auth1000');

BEGIN;

	-- add authorization for row 1000
	SELECT postgis_AddAuth('auth1000');
	
	-- we're authorized for row 1000
	DELETE FROM test_long_term_locks WHERE id = 3000;

END;

-- release the auth3000 locks
SELECT postgis_UnlockRows('auth3000');

-- look at the long term locks table
SELECT * FROM test_long_term_locks;

-- drop the long term locks table
DROP TABLE test_long_term_locks;

-- disable long transaction support
SELECT postgis_DisableLongTransactions();